@@ -68,12 +68,14 @@
 (ns com.puppetlabs.puppetdb.http.v1.resources
   (:require [com.puppetlabs.http :as pl-http]
             [com.puppetlabs.puppetdb.query.resources :as r]
-            [cheshire.core :as json]
+            [com.puppetlabs.cheshire :as json]
             [ring.util.response :as rr])
   (:use [net.cgrand.moustache :only [app]]
         com.puppetlabs.middleware
         [com.puppetlabs.jdbc :only (with-transacted-connection)]))
 
+(def version :v1)
+
 (defn munge-result-rows
   "Munge the result rows so that they will be compatible with the v1 API specification"
   [rows]
@@ -84,21 +86,18 @@
     rows))
 
 (defn produce-body
-  "Given a `limit`, a query, and database connection, return a Ring
+  "Given a query, and database connection, return a Ring
   response with the query results. The result format conforms to that documented
   above.
 
   If the query can't be parsed, a 400 is returned.
 
   If the query would return more than `limit` results, `status-internal-error` is returned."
-  [limit query db]
-  {:pre [(and (integer? limit) (>= limit 0))]}
+  [query db]
   (try
     (with-transacted-connection db
-      (-> query
-          (json/parse-string true)
-          (r/v1-query->sql)
-          ((partial r/limited-query-resources limit))
+      (-> (r/query->sql version (json/parse-string query true))
+          (r/query-resources)
           (:result)
           (munge-result-rows)
           (pl-http/json-response)))
@@ -113,7 +112,9 @@
   (app
     [""]
     {:get (fn [{:keys [params globals]}]
-            (produce-body (:resource-query-limit globals) (params "query") (:scf-db globals)))}))
+            (produce-body
+              (params "query")
+              (:scf-read-db globals)))}))
 
 (def resources-app
   "Ring app for querying resources"
