@@ -173,36 +173,21 @@
         query (format "NOT (%s)" (:where compiled-term))]
     (assoc compiled-term :where query)))
 
-(defn compile-not-v1
-  "Compile a v1 NOT operator, applied to `terms`. This term is true if *every*
-  argument term is false. The compilation is effectively to apply an OR
-  operation to the terms, and then NOT that result."
-  [ops & terms]
-  {:pre  [(every? sequential? terms)]
-   :post [(string? (:where %))]}
-  (when (empty? terms)
-    (throw (IllegalArgumentException. (str "not requires at least one term"))))
-  (negate-term* ops (cons "or" terms)))
-
-(defn compile-not-v2
-  "Compile a v2 NOT operator, applied to `term`. This term simply negates the
+(defn compile-not
+  "Compile a NOT operator, applied to `term`. This term simply negates the
   value of `term`. Basically this function just serves as error checking for
   `negate-term*`."
-  [ops & terms]
+  [version ops & terms]
   {:post [(string? (:where %))]}
-  (when-not (= (count terms) 1)
-    (throw (IllegalArgumentException. (format "'not' takes exactly one argument, but %d were supplied" (count terms)))))
-  (negate-term* ops (first terms)))
-
-(defn compile-not-v3
-  "Compile a v3 NOT operator, applied to `term`. This term simply negates the
-  value of `term`. Basically this function just serves as error checking for
-  `negate-term*`."
-  [ops & terms]
-  {:post [(string? (:where %))]}
-  (when-not (= (count terms) 1)
-    (throw (IllegalArgumentException. (format "'not' takes exactly one argument, but %d were supplied" (count terms)))))
-  (negate-term* ops (first terms)))
+  (case version
+    :v1 (do
+          (when (empty? terms)
+            (throw (IllegalArgumentException. (str "not requires at least one term"))))
+          (negate-term* ops (cons "or" terms)))
+    (do
+      (when-not (= (count terms) 1)
+        (throw (IllegalArgumentException. (format "'not' takes exactly one argument, but %d were supplied" (count terms)))))
+      (negate-term* ops (first terms)))))
 
 ;; This map's keys are the queryable fields for facts, and the values are the
 ;;  corresponding table names where the fields reside
@@ -248,11 +233,12 @@
 
 (defmethod queryable-fields :resource
   [_ query-api-version]
-  (condp = query-api-version
-    3 (keyset resource-columns)
-    2 (-> (keyset resource-columns)
-        (set/union (keyset v3-renamed-resource-columns))
-        (set/difference (valset v3-renamed-resource-columns)))))
+  (case query-api-version
+    :v1 (throw (IllegalArgumentException. "queryable fields for resources not supported for v1"))
+    :v2 (-> (keyset resource-columns)
+            (set/union (keyset v3-renamed-resource-columns))
+            (set/difference (valset v3-renamed-resource-columns)))
+    (keyset resource-columns)))
 
 (defmethod queryable-fields :fact
   [_ _]
@@ -332,119 +318,94 @@
         sql (format "SELECT %s FROM certnames WHERE %s" (column-map->sql node-columns) where)]
     (apply vector sql params)))
 
-(defn compile-resource-equality-v3
-  "Compile an = operator for a v3 resource query. `path` represents the field
-  to query against, and `value` is the value."
-  [& [path value :as args]]
-  {:post [(map? %)
-          (:where %)]}
-  (when-not (= (count args) 2)
-    (throw (IllegalArgumentException. (format "= requires exactly two arguments, but %d were supplied" (count args)))))
-  (match [path]
-         ;; tag join. Tags are case-insensitive but always lowercase, so
-         ;; lowercase the query value.
-         ["tag"]
-         {:where  (sql-array-query-string "tags")
-          :params [(string/lower-case value)]}
-
-         ;; node join.
-         ["certname"]
-         {:where  "catalogs.certname = ?"
-          :params [value]}
-
-         ;; {in,}active nodes.
-         [["node" "active"]]
-         {
-           :where (format "catalogs.certname IN (SELECT name FROM certnames WHERE deactivated IS %s)" (if value "NULL" "NOT NULL"))}
-
-         ;; param joins.
-         [["parameter" (name :guard string?)]]
-         {:where  "catalog_resources.resource IN (SELECT rp.resource FROM resource_params rp WHERE rp.name = ? AND rp.value = ?)"
-          :params [name (db-serialize value)]}
-
-         ;; metadata match.
-         [(metadata :guard #{"catalog" "resource" "type" "title" "tags" "exported" "file" "line"})]
-           {:where  (format "catalog_resources.%s = ?" metadata)
-            :params [value]}
-
-         ;; ...else, failure
-         :else (throw (IllegalArgumentException.
-                       (str path " is not a queryable object for resources")))))
-
-(defn compile-resource-equality-v2
-  "Compile an = operator for a v2 resource query. `path` represents the field
-  to query against, and `value` is the value. This mostly just defers to
-  `compile-resource-equality-v3`, with a little bit of logic to handle the one
-  term that differs."
-  [& [path value :as args]]
-  {:post [(map? %)
-          (:where %)]}
-  (when-not (= (count args) 2)
-    (throw (IllegalArgumentException. (format "= requires exactly two arguments, but %d were supplied" (count args)))))
-  ;; If they passed in any of the new names for the renamed resource-columns, we fail
-  ;; because this is v2.
-  (when (contains? (valset v3-renamed-resource-columns) path)
-    (throw (IllegalArgumentException. (format "%s is not a queryable object for resources" path))))
-  (compile-resource-equality-v3 (get v3-renamed-resource-columns path path) value))
-
-(defn compile-resource-equality-v1
-  "Compile an = operator for a v1 resource query. `path` represents the field
+(defn compile-resource-equality
+  "Compile an = operator for a resource query. `path` represents the field
   to query against, and `value` is the value. This mostly just defers to
   `compile-resource-equality-v2`, with a little bit of logic to handle the one
   term that differs."
-  [& [path value :as args]]
+  [version & [path value :as args]]
   {:post [(map? %)
           (:where %)]}
   (when-not (= (count args) 2)
     (throw (IllegalArgumentException. (format "= requires exactly two arguments, but %d were supplied" (count args)))))
-  ;; We call it "certname" in v2, and ["node" "name"] in v1. If they specify
-  ;; ["node" "name"], rewrite it as "certname". But if they specify "certname",
-  ;; fail because this is v1.
-  (when (= path "certname")
-    (throw (IllegalArgumentException. "certname is not a queryable object for resources")))
-  (let [path (if (= path ["node" "name"]) "certname" path)]
-    (compile-resource-equality-v2 path value)))
+  (case version
+    :v1 (do
+          ;; We call it "certname" in v2, and ["node" "name"] in v1. If they specify
+          ;; ["node" "name"], rewrite it as "certname". But if they specify "certname",
+          ;; fail because this is v1.
+          (when (= path "certname")
+            (throw (IllegalArgumentException. "certname is not a queryable object for resources")))
+          (let [path (if (= path ["node" "name"]) "certname" path)]
+            (compile-resource-equality :v2 path value)))
+    :v2 (do
+          ;; If they passed in any of the new names for the renamed resource-columns, we fail
+          ;; because this is v2.
+          (when (contains? (valset v3-renamed-resource-columns) path)
+            (throw (IllegalArgumentException. (format "%s is not a queryable object for resources" path))))
+          (compile-resource-equality :v3 (get v3-renamed-resource-columns path path) value))
+    (do
+      (match [path]
+             ;; tag join. Tags are case-insensitive but always lowercase, so
+             ;; lowercase the query value.
+             ["tag"]
+             {:where  (sql-array-query-string "tags")
+              :params [(string/lower-case value)]}
 
-(defn compile-resource-regexp-v3
-  "Compile an '~' predicate for a v3 resource query, which does regexp matching.
+             ;; node join.
+             ["certname"]
+             {:where  "catalogs.certname = ?"
+              :params [value]}
+
+             ;; {in,}active nodes.
+             [["node" "active"]]
+             {
+               :where (format "catalogs.certname IN (SELECT name FROM certnames WHERE deactivated IS %s)" (if value "NULL" "NOT NULL"))}
+
+             ;; param joins.
+             [["parameter" (name :guard string?)]]
+             {:where  "catalog_resources.resource IN (SELECT rp.resource FROM resource_params rp WHERE rp.name = ? AND rp.value = ?)"
+              :params [name (db-serialize value)]}
+
+             ;; metadata match.
+             [(metadata :guard #{"catalog" "resource" "type" "title" "tags" "exported" "file" "line"})]
+               {:where  (format "catalog_resources.%s = ?" metadata)
+                :params [value]}
+
+             ;; ...else, failure
+             :else (throw (IllegalArgumentException.
+                           (str path " is not a queryable object for resources")))))))
+
+(defn compile-resource-regexp
+  "Compile an '~' predicate for a resource query, which does regexp matching.
   This is done by leveraging the correct database-specific regexp syntax to
   return only rows where the supplied `path` match the given `pattern`."
-  [path pattern]
+  [version & [path value :as args]]
   {:post [(map? %)
           (:where %)]}
-  (match [path]
-         ["tag"]
-         {:where (sql-regexp-array-match "catalog_resources" "tags")
-          :params [pattern]}
+  (case version
+    :v1 (throw (IllegalArgumentException. (format "No support for regexp for v1 api")))
+    :v2 (do
+          (when (contains? (valset v3-renamed-resource-columns) path)
+            (throw (IllegalArgumentException. (format "%s cannot be the target of a regexp match" path))))
+          (compile-resource-regexp :v3 (get v3-renamed-resource-columns path path) value))
+    (match [path]
+           ["tag"]
+           {:where (sql-regexp-array-match "catalog_resources" "tags")
+            :params [value]}
 
-         ;; node join.
-         ["certname"]
-         {:where  (sql-regexp-match "catalogs.certname")
-          :params [pattern]}
+           ;; node join.
+           ["certname"]
+           {:where  (sql-regexp-match "catalogs.certname")
+            :params [value]}
 
-         ;; metadata match.
-         [(metadata :guard #{"type" "title" "exported" "file"})]
-         {:where  (sql-regexp-match (format "catalog_resources.%s" metadata))
-          :params [pattern]}
+           ;; metadata match.
+           [(metadata :guard #{"type" "title" "exported" "file"})]
+           {:where  (sql-regexp-match (format "catalog_resources.%s" metadata))
+            :params [value]}
 
-         ;; ...else, failure
-         :else (throw (IllegalArgumentException.
-                        (str path " cannot be the target of a regexp match")))))
-
-(defn compile-resource-regexp-v2
-  "Compile an '~' predicate for a v2 resource query, which does regexp matching.
-  This is done by leveraging the correct database-specific regexp syntax to
-  return only rows where the supplied `path` match the given `pattern`.  This
-  mostly just defers to `compile-resource-regexp-v2`, with a little bit of logic to
-  handle the terms that differ."
-  [& [path value :as args]]
-  {:post [(map? %)
-          (:where %)]}
-  ;; If they passed in any of the new names for the renamed resource-columns, we fail
-  ;; because this is v2.
-  (when (contains? (valset v3-renamed-resource-columns) path)
-    (throw (IllegalArgumentException. (format "%s cannot be the target of a regexp match" path))))
-  (compile-resource-regexp-v3 (get v3-renamed-resource-columns path path) value))
+           ;; ...else, failure
+           :else (throw (IllegalArgumentException.
+                          (str path " cannot be the target of a regexp match"))))))
 
 (defn compile-fact-equality
   "Compile an = predicate for a fact query. `path` represents the field to
@@ -515,59 +476,34 @@
     (throw (IllegalArgumentException.
             (format "Value %s must be a number for %s comparison." value op)))))
 
-(defn compile-node-equality-v1
-  "Compile a v1 equality operator for nodes. This can either be for the value of
+(defn compile-node-equality
+  "Compile an equality operator for nodes. This can either be for the value of
   a specific fact, or based on node activeness."
-  [path value]
+  [version path value]
   {:post [(map? %)
           (string? (:where %))]}
-  (match [path]
-         [["fact" (name :guard string?)]]
-         {:where  "certnames.name IN (SELECT cf.certname FROM certname_facts cf WHERE cf.name = ? AND cf.value = ?)"
-          :params [name (str value)]}
-         [["node" "active"]]
-         {:where (format "certnames.deactivated IS %s" (if value "NULL" "NOT NULL"))}
+  (case version
+    :v1 (match [path]
+          [["fact" (name :guard string?)]]
+          {:where  "certnames.name IN (SELECT cf.certname FROM certname_facts cf WHERE cf.name = ? AND cf.value = ?)"
+           :params [name (str value)]}
+          [["node" "active"]]
+          {:where (format "certnames.deactivated IS %s" (if value "NULL" "NOT NULL"))}
 
-         :else (throw (IllegalArgumentException.
-                        (str path " is not a queryable object for nodes")))))
+          :else (throw (IllegalArgumentException.
+                         (str path " is not a queryable object for nodes"))))
+    (match [path]
+           ["name"]
+           {:where "certnames.name = ?"
+            :params [value]}
+           [["fact" (name :guard string?)]]
+           {:where  "certnames.name IN (SELECT cf.certname FROM certname_facts cf WHERE cf.name = ? AND cf.value = ?)"
+            :params [name (str value)]}
+           [["node" "active"]]
+           {:where (format "certnames.deactivated IS %s" (if value "NULL" "NOT NULL"))}
 
-(defn compile-node-equality-v2
-  "Compile a v2 equality operator for nodes. This can either be for the value of
-  a specific fact, or based on node activeness."
-  [path value]
-  {:post [(map? %)
-          (string? (:where %))]}
-  (match [path]
-         ["name"]
-         {:where "certnames.name = ?"
-          :params [value]}
-         [["fact" (name :guard string?)]]
-         {:where  "certnames.name IN (SELECT cf.certname FROM certname_facts cf WHERE cf.name = ? AND cf.value = ?)"
-          :params [name (str value)]}
-         [["node" "active"]]
-         {:where (format "certnames.deactivated IS %s" (if value "NULL" "NOT NULL"))}
-
-         :else (throw (IllegalArgumentException.
-                        (str path " is not a queryable object for nodes")))))
-
-(defn compile-node-equality-v3
-  "Compile a v3 equality operator for nodes. This can either be for the value of
-  a specific fact, or based on node activeness."
-  [path value]
-  {:post [(map? %)
-          (string? (:where %))]}
-  (match [path]
-         ["name"]
-         {:where "certnames.name = ?"
-          :params [value]}
-         [["fact" (name :guard string?)]]
-         {:where  "certnames.name IN (SELECT cf.certname FROM certname_facts cf WHERE cf.name = ? AND cf.value = ?)"
-          :params [name (str value)]}
-         [["node" "active"]]
-         {:where (format "certnames.deactivated IS %s" (if value "NULL" "NOT NULL"))}
-
-         :else (throw (IllegalArgumentException.
-                        (str path " is not a queryable object for nodes")))))
+           :else (throw (IllegalArgumentException.
+                          (str path " is not a queryable object for nodes"))))))
 
 (defn compile-node-regexp
   "Compile an '~' predicate for a fact query, which does regexp matching.  This
@@ -605,168 +541,89 @@
     (throw (IllegalArgumentException.
             (format "Value %s must be a number for %s comparison." value op)))))
 
-(declare fact-operators-v2)
-(declare fact-operators-v3)
+(declare fact-operators)
 
-(defn resource-operators-v1
-  "Maps v1 resource query operators to the functions implementing them. Returns nil
+(defn resource-operators
+  "Maps resource query operators to the functions implementing them. Returns nil
   if the operator isn't known."
-  [op]
-  (let [unsupported (fn [& args]
-                      (throw (IllegalArgumentException. (format "Operator '%s' is not available in v1 resource queries" op))))]
-    (condp = (string/lower-case op)
-      "=" compile-resource-equality-v1
-      "and" (partial compile-and resource-operators-v1)
-      "or" (partial compile-or resource-operators-v1)
-      "not" (partial compile-not-v1 resource-operators-v1)
-      ;; All the subquery operators are unsupported in v1, so we dispatch to a
-      ;; function that throws an exception
-      "extract" unsupported
-      "in" unsupported
-      "select-resources" unsupported
-      "select-facts" unsupported
-      nil)))
+  [version]
+  (case version
+    :v1 (fn [op]
+          (let [unsupported (fn [& args]
+                              (throw (IllegalArgumentException. (format "Operator '%s' is not available in v1 resource queries" op))))]
+            (condp = (string/lower-case op)
+              "=" (partial compile-resource-equality version)
+              "and" (partial compile-and (resource-operators version))
+              "or" (partial compile-or (resource-operators version))
+              "not" (partial compile-not version (resource-operators version))
+              ;; All the subquery operators are unsupported in v1, so we dispatch to a
+              ;; function that throws an exception
+              "extract" unsupported
+              "in" unsupported
+              "select-resources" unsupported
+              "select-facts" unsupported
+              nil)))
+    (fn [op]
+      (condp = (string/lower-case op)
+        "=" (partial compile-resource-equality version)
+        "~" (partial compile-resource-regexp version)
+        "and" (partial compile-and (resource-operators version))
+        "or" (partial compile-or (resource-operators version))
+        "not" (partial compile-not version (resource-operators version))
+        "extract" (partial compile-extract version (resource-operators version))
+        "in" (partial compile-in :resource version (resource-operators version))
+        "select-resources" (partial resource-query->sql (resource-operators version))
+        "select-facts" (partial fact-query->sql (fact-operators version))
+        nil))))
 
-(defn resource-operators-v2
-  "Maps v2 resource query operators to the functions implementing them. Returns nil
+(defn fact-operators
+  "Maps fact query operators to the functions implementing them. Returns nil
   if the operator isn't known."
-  [op]
-  (condp = (string/lower-case op)
-    "=" compile-resource-equality-v2
-    "~" compile-resource-regexp-v2
-    "and" (partial compile-and resource-operators-v2)
-    "or" (partial compile-or resource-operators-v2)
-    "not" (partial compile-not-v2 resource-operators-v2)
-    "extract" (partial compile-extract 2 resource-operators-v2)
-    "in" (partial compile-in :resource 2 resource-operators-v2)
-    "select-resources" (partial resource-query->sql resource-operators-v2)
-    "select-facts" (partial fact-query->sql fact-operators-v2)
-    nil))
+  [version]
+  (fn [op]
+    (let [op (string/lower-case op)]
+      (cond
+        (#{">" "<" ">=" "<="} op)
+        (partial compile-fact-inequality op)
 
-(defn resource-operators-v3
-  "Maps v3 resource query operators to the functions implementing them. Returns nil
+        (= op "=") compile-fact-equality
+        (= op "~") compile-fact-regexp
+        ;; We pass this function along so the recursive calls know which set of
+        ;; operators/functions to use, depending on the API version.
+        (= op "and") (partial compile-and (fact-operators version))
+        (= op "or") (partial compile-or (fact-operators version))
+        (= op "not") (partial compile-not version (fact-operators version))
+        (= op "extract") (partial compile-extract version (fact-operators version))
+        (= op "in") (partial compile-in :fact version (fact-operators version))
+        (= op "select-resources") (partial resource-query->sql (resource-operators version))
+        (= op "select-facts") (partial fact-query->sql (fact-operators version))))))
+
+(defn node-operators
+  "Maps node query operators to the functions implementing them. Returns nil
   if the operator isn't known."
-  [op]
-  (condp = (string/lower-case op)
-    "=" compile-resource-equality-v3
-    "~" compile-resource-regexp-v3
-    "and" (partial compile-and resource-operators-v3)
-    "or" (partial compile-or resource-operators-v3)
-    "not" (partial compile-not-v3 resource-operators-v3)
-    "extract" (partial compile-extract 3 resource-operators-v3)
-    "in" (partial compile-in :resource 3 resource-operators-v3)
-    "select-resources" (partial resource-query->sql resource-operators-v3)
-    "select-facts" (partial fact-query->sql fact-operators-v3)
-    nil))
-
-(defn fact-operators-v1
-  "Maps v2 fact query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)]
-    (cond
-      (#{">" "<" ">=" "<="} op)
-      (partial compile-fact-inequality op)
-
-      (= op "=") compile-fact-equality
-      (= op "~") compile-fact-regexp
-      ;; We pass this function along so the recursive calls know which set of
-      ;; operators/functions to use, depending on the API version.
-      (= op "and") (partial compile-and fact-operators-v1)
-      (= op "or") (partial compile-or fact-operators-v1)
-      (= op "not") (partial compile-not-v1 fact-operators-v1)
-      (= op "extract") (partial compile-extract 1 fact-operators-v1)
-      (= op "in") (partial compile-in :fact 1 fact-operators-v1)
-      (= op "select-resources") (partial resource-query->sql resource-operators-v1)
-      (= op "select-facts") (partial fact-query->sql fact-operators-v1))))
-
-(defn fact-operators-v2
-  "Maps v2 fact query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)]
-    (cond
-      (#{">" "<" ">=" "<="} op)
-      (partial compile-fact-inequality op)
-
-      (= op "=") compile-fact-equality
-      (= op "~") compile-fact-regexp
-      ;; We pass this function along so the recursive calls know which set of
-      ;; operators/functions to use, depending on the API version.
-      (= op "and") (partial compile-and fact-operators-v2)
-      (= op "or") (partial compile-or fact-operators-v2)
-      (= op "not") (partial compile-not-v2 fact-operators-v2)
-      (= op "extract") (partial compile-extract 2 fact-operators-v2)
-      (= op "in") (partial compile-in :fact 2 fact-operators-v2)
-      (= op "select-resources") (partial resource-query->sql resource-operators-v2)
-      (= op "select-facts") (partial fact-query->sql fact-operators-v2))))
-
-(defn fact-operators-v3
-  "Maps v3 fact query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)]
-    (cond
-      (#{">" "<" ">=" "<="} op)
-      (partial compile-fact-inequality op)
-
-      (= op "=") compile-fact-equality
-      (= op "~") compile-fact-regexp
-      ;; We pass this function along so the recursive calls know which set of
-      ;; operators/functions to use, depending on the API version.
-      (= op "and") (partial compile-and fact-operators-v3)
-      (= op "or") (partial compile-or fact-operators-v3)
-      (= op "not") (partial compile-not-v3 fact-operators-v3)
-      (= op "extract") (partial compile-extract 3 fact-operators-v3)
-      (= op "in") (partial compile-in :fact 3 fact-operators-v3)
-      (= op "select-resources") (partial resource-query->sql resource-operators-v3)
-      (= op "select-facts") (partial fact-query->sql fact-operators-v3))))
-
-(defn node-operators-v1
-  "Maps v1 node query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)
-        unsupported (fn [& args]
-                      (throw (IllegalArgumentException. (format "Operator '%s' is not available in v1 node queries" op))))]
-    (cond
-      (= op "=") compile-node-equality-v1
-      (#{">" "<" ">=" "<="} op) (partial compile-node-inequality op)
-      (= op "and") (partial compile-and node-operators-v1)
-      (= op "or") (partial compile-or node-operators-v1)
-      (= op "not") (partial compile-not-v1 node-operators-v1)
-      (#{"~" "extract" "in" "select-resources" "select-facts"} op) unsupported)))
-
-(defn node-operators-v2
-  "Maps v2 node query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)]
-    (cond
-      (= op "=") compile-node-equality-v2
-      (= op "~") compile-node-regexp
-      (#{">" "<" ">=" "<="} op) (partial compile-node-inequality op)
-      (= op "and") (partial compile-and node-operators-v2)
-      (= op "or") (partial compile-or node-operators-v2)
-      (= op "not") (partial compile-not-v2 node-operators-v2)
-      (= op "extract") (partial compile-extract 2 node-operators-v2)
-      (= op "in") (partial compile-in :node 2 node-operators-v2)
-      (= op "select-resources") (partial resource-query->sql resource-operators-v2)
-      (= op "select-facts") (partial fact-query->sql fact-operators-v2))))
-
-(defn node-operators-v3
-  "Maps v3 node query operators to the functions implementing them. Returns nil
-  if the operator isn't known."
-  [op]
-  (let [op (string/lower-case op)]
-    (cond
-      (= op "=") compile-node-equality-v3
-      (= op "~") compile-node-regexp
-      (#{">" "<" ">=" "<="} op) (partial compile-node-inequality op)
-      (= op "and") (partial compile-and node-operators-v3)
-      (= op "or") (partial compile-or node-operators-v3)
-      (= op "not") (partial compile-not-v3 node-operators-v3)
-      (= op "extract") (partial compile-extract 3 node-operators-v3)
-      (= op "in") (partial compile-in :node 3 node-operators-v3)
-      (= op "select-resources") (partial resource-query->sql resource-operators-v3)
-      (= op "select-facts") (partial fact-query->sql fact-operators-v3))))
+  [version]
+  (case version
+    :v1 (fn [op]
+          (let [op (string/lower-case op)
+                unsupported (fn [& args]
+                              (throw (IllegalArgumentException. (format "Operator '%s' is not available in v1 node queries" op))))]
+            (cond
+              (= op "=") (partial compile-node-equality version)
+              (#{">" "<" ">=" "<="} op) (partial compile-node-inequality op)
+              (= op "and") (partial compile-and (node-operators version))
+              (= op "or") (partial compile-or (node-operators version))
+              (= op "not") (partial compile-not version (node-operators version))
+              (#{"~" "extract" "in" "select-resources" "select-facts"} op) unsupported)))
+    (fn [op]
+      (let [op (string/lower-case op)]
+        (cond
+          (= op "=") (partial compile-node-equality version)
+          (= op "~") compile-node-regexp
+          (#{">" "<" ">=" "<="} op) (partial compile-node-inequality op)
+          (= op "and") (partial compile-and (node-operators version))
+          (= op "or") (partial compile-or (node-operators version))
+          (= op "not") (partial compile-not version (node-operators version))
+          (= op "extract") (partial compile-extract version (node-operators version))
+          (= op "in") (partial compile-in :node version (node-operators version))
+          (= op "select-resources") (partial resource-query->sql (resource-operators version))
+          (= op "select-facts") (partial fact-query->sql (fact-operators version)))))))
