@@ -4,7 +4,7 @@
   (:refer-clojure :exclude [case compile conj! distinct disj! drop sort take])
   (:require [clojure.string :as string]
             [com.puppetlabs.jdbc :as sql])
-  (:use [com.puppetlabs.puppetdb.query :only [fact-query->sql fact-operators-v1 fact-operators-v2 fact-operators-v3 execute-query]]
+  (:use [com.puppetlabs.puppetdb.query :only [fact-query->sql fact-operators execute-query]]
         [com.puppetlabs.puppetdb.query.paging :only [validate-order-by!]]))
 
 (defn facts-for-node
@@ -57,12 +57,13 @@
 
 (defn query->sql
   "Compile a query into an SQL expression."
-  [operators query paging-options]
+  [version query paging-options]
   {:pre [((some-fn nil? sequential?) query) ]
    :post [(map? %)
           (string? (first (:results-query %)))
           (every? (complement coll?) (rest (:results-query %)))]}
-  (let [[sql & params] (facts-sql operators query paging-options)]
+  (let [operators (fact-operators version)
+        [sql & params] (facts-sql operators query paging-options)]
     (conj {:results-query (apply vector (sql/paged-sql sql paging-options) params)}
           (when (:count? paging-options)
             [:count-query (apply vector (sql/count-sql sql) params)]))))
@@ -77,12 +78,3 @@
   (validate-order-by! [:certname :name :value] paging-options)
   (sql/with-query-results-cursor query params rs
     (func rs)))
-
-(def v1-query->sql
-  (partial query->sql fact-operators-v1))
-
-(def v2-query->sql
-  (partial query->sql fact-operators-v2))
-
-(def v3-query->sql
-  (partial query->sql fact-operators-v3))
