@@ -8,7 +8,7 @@
   (:require [clojure.string :as string])
   (:use [com.puppetlabs.puppetdb.scf.storage-utils :only [db-serialize sql-array-query-string sql-as-numeric]]
         [clojure.core.match :only [match]]
-        [com.puppetlabs.puppetdb.query :only [node-query->sql node-operators-v1 node-operators-v2 node-operators-v3 execute-query]]
+        [com.puppetlabs.puppetdb.query :only [node-query->sql node-operators execute-query]]
         [com.puppetlabs.jdbc :only [query-to-vec with-transacted-connection valid-jdbc-query?]]
         [puppetlabs.kitchensink.core :only [keyset parse-number]]
         [com.puppetlabs.puppetdb.query.paging :only [validate-order-by!]]))
@@ -19,10 +19,11 @@
 (defn query->sql
   "Converts a vector-structured `query` to a corresponding SQL query which will
   return nodes matching the `query`."
-  [operators query]
+  [version query]
   {:pre  [((some-fn nil? sequential?) query)]
    :post [(valid-jdbc-query? %)]}
-  (let [[subselect & params] (if query
+  (let [operators (node-operators version)
+        [subselect & params] (if query
                                (node-query->sql operators query)
                                ["SELECT name, deactivated FROM certnames"])
         sql (format "SELECT subquery1.name,
@@ -49,23 +50,14 @@
     (validate-order-by! node-columns paging-options)
     (execute-query filter-expr paging-options)))
 
-(def v1-query->sql
-  (partial query->sql node-operators-v1))
-
-(def v2-query->sql
-  (partial query->sql node-operators-v2))
-
-(def v3-query->sql
-  (partial query->sql node-operators-v3))
-
 (defn status
   "Given a node's name, return the current status of the node.  Results
   include whether it's active and the timestamp of its most recent catalog, facts,
   and report."
-  [node]
+  [version node]
   {:pre  [string? node]
    :post [(or (nil? %)
               (= #{:name :deactivated :catalog_timestamp :facts_timestamp :report_timestamp} (keyset %)))]}
-  (let [sql     (query->sql node-operators-v2 ["=" "name" node])
+  (let [sql     (query->sql version ["=" "name" node])
         results (query-to-vec sql)]
     (first results)))
