@@ -23,6 +23,10 @@
                                :type      :string }
    })
 
+(def report-fields
+  "Report fields"
+  (keys (:fields Report)))
+
 (defmodel ResourceEvent
   {:status             :string
    :timestamp          :datetime
@@ -44,6 +48,10 @@
                          :type      :coll }
    })
 
+(def resource-event-fields
+  "Resource event fields"
+  (keys (:fields ResourceEvent)))
+
 (def v2-new-event-fields [:file :line])
 
 (defn validate-and-add-v2-event-field!
@@ -87,3 +95,24 @@
                (format "Containment path should only contain strings: '%s'"
                        (resource-event :containment-path))))))
   report)
+
+(defn sanitize-events
+  "This function takes an array of events and santizes them, ensuring only
+   valid keys are returned."
+  [events]
+  {:pre [(coll? events)]
+   :post [(coll? %)]}
+  (let [valid-keys (map name resource-event-fields)]
+    (for [event events]
+      (select-keys event valid-keys))))
+
+(defn sanitize-report
+  "This function takes a report and sanitizes it, ensuring only valid data
+   is left over."
+  [payload]
+  {:pre [(map? payload)]
+   :post [(map? %)]}
+  (let [valid-keys (map name report-fields)]
+    (-> payload
+      (select-keys valid-keys)
+      (update-in ["resource-events"] sanitize-events))))
