@@ -267,7 +267,7 @@
     ["SELECT id, hash FROM catalogs WHERE certname=?" certname]
     (first result-set)))
 
-(sm/defn update-catalog-metadata!
+(pls/defn-validated update-catalog-metadata!
   "Given some catalog metadata, update the db"
   [id :- Number
    hash :- String
@@ -281,7 +281,7 @@
                       :transaction_uuid transaction-uuid
                       :timestamp (to-timestamp timestamp)}))
 
-(sm/defn add-catalog-metadata!
+(pls/defn-validated add-catalog-metadata!
   "Given some catalog metadata, persist it in the db. Returns a map of the
   inserted data including any autogenerated columns."
   [hash :- String
@@ -301,7 +301,7 @@
       (first (query-to-vec ["SELECT * FROM catalogs WHERE hash = ?" hash]))
       return)))
 
-(sm/defn resources-exist? :- #{String}
+(pls/defn-validated resources-exist? :- #{String}
   "Given a collection of resource-hashes, return the subset that
   already exist in the database."
   [resource-hashes :- #{String}]
@@ -315,17 +315,21 @@
       sql-params
       (set (map :resource result-set)))))
 
-(sm/defn catalog-resources :- {resource-ref-schema String}
+;;The schema definition of this function should be
+;;resource-ref->resource-schema, but there are a lot of tests that
+;;have incorrect data. When examples.clj and tests get fixed, this
+;;should be changed to the correct schema
+(pls/defn-validated catalog-resources
   "Returns the resource hashes keyed by resource reference"
   [catalog-id :- Number]
   (sql/with-query-results result-set
-    ["SELECT resource as hash, type, title
-                 FROM catalog_resources
-                 WHERE catalog_id = ?" catalog-id]
+    ["SELECT type, title, tags, exported, file, line, resource
+      FROM catalog_resources
+      WHERE catalog_id = ?" catalog-id]
     (zipmap (map #(select-keys % [:type :title]) result-set)
-            (map :hash result-set))))
+            (jdbc/convert-result-arrays set result-set))))
 
-(sm/defn new-params-only
+(pls/defn-validated new-params-only
   "Returns a map of not persisted parameters, keyed by hash"
   [persisted-params :- #{String}
    refs-to-resources :- resource-ref->resource-schema
@@ -337,14 +341,14 @@
                    (assoc acc resource-hash parameters))))
              {} refs-to-resources))
 
-(sm/defn insert-records*
+(pls/defn-validated insert-records*
   "Nil/empty safe insert-records, see java.jdbc's insert-records for more "
   [table :- s/Keyword
    record-coll :- [{s/Keyword s/Any}]]
   (when (seq record-coll)
     (apply sql/insert-records table record-coll)))
 
-(sm/defn add-params!
+(pls/defn-validated add-params!
   "Persists the new parameters found in `refs-to-resources` and populates the
    resource_params_cache."
   [refs-to-resources :- resource-ref->resource-schema
@@ -371,7 +375,14 @@
   "Returns true of the map is a resource reference"
   (every-pred :type :title))
 
-(sm/defn insert-catalog-resources!
+(defn convert-tags-array
+  "Converts the given tags (if present) to the format the database expects"
+  [resource]
+  (if (contains? resource :tags)
+    (update-in resource [:tags] sutils/to-jdbc-varchar-array)
+    resource))
+
+(pls/defn-validated insert-catalog-resources!
   "Returns a function that accepts a seq of ref keys to insert"
   [catalog-id :- Number
    refs-to-hashes :- {resource-ref-schema String}
@@ -385,17 +396,18 @@
      :catalog_resources
      (map (fn [resource-ref]
             (let [{:keys [type title exported parameters tags file line] :as resource} (get refs-to-resources resource-ref)]
-              {:catalog_id catalog-id
-               :resource (get refs-to-hashes resource-ref)
-               :type type
-               :title title
-               :tags (sutils/to-jdbc-varchar-array tags)
-               :exported exported
-               :file file
-               :line line}))
+              (convert-tags-array
+               {:catalog_id catalog-id
+                :resource (get refs-to-hashes resource-ref)
+                :type type
+                :title title
+                :tags tags
+                :exported exported
+                :file file
+                :line line})))
           refs-to-insert))))
 
-(sm/defn delete-catalog-resources!
+(pls/defn-validated delete-catalog-resources!
   "Returns a function accepts old catalog resources that should be deleted."
   [catalog-id :- Number]
   (fn [refs-to-delete]
@@ -406,38 +418,77 @@
     (doseq [{:keys [type title]} refs-to-delete]
       (sql/delete-rows :catalog_resources ["catalog_id = ? and type = ? and title = ?" catalog-id type title]))))
 
-(sm/defn update-catalog-resources!
-  "Returns a function accepting keys that were the same from the old resoruces and the new resources."
+(sm/defn basic-diff
+  "Basic diffing that returns only the keys/values of `right` whose values don't match those of `left`.
+   This is different from clojure.data/diff in that it treats non-equal sets as completely different
+   (rather than returning only the differing items of the set) and only returns differences from `right`."
+  [left right]
+  (reduce-kv (fn [acc k right-value]
+               (let [left-value (get left k)]
+                 (if (= left-value right-value)
+                   acc
+                   (assoc acc k right-value))))
+             {} right))
+
+(sm/defn diff-resources-metadata
+  "Return resource references with values that are only the key/values that from `right` that
+   are different from those of the `left`. The keys/values here are suitable for issuing update
+   statements that will update resources to the correct (new) values."
+  [left right]
+  (reduce-kv (fn [acc k right-values]
+               (let [updated-resource-vals (basic-diff (get left k) right-values)]
+                 (if (seq updated-resource-vals)
+                   (assoc acc k updated-resource-vals)
+                   acc))) {} right))
+
+(defn merge-resource-hash
+  "Assoc each hash from `refs-to-hashes` as :resource on `refs-to-resources`"
+  [refs-to-hashes refs-to-resources]
+  (reduce-kv (fn [acc k v]
+               (assoc-in acc [k :resource] (get refs-to-hashes k)))
+             refs-to-resources refs-to-resources))
+
+(pls/defn-validated update-catalog-resources!
+  "Returns a function accepting keys that were the same from the old resources and the new resources."
   [catalog-id :- Number
    refs-to-hashes :- {resource-ref-schema String}
-   old-resources :- {resource-ref-schema String}]
+   refs-to-resources
+   old-resources]
 
   (fn [maybe-updated-refs]
     {:pre [(every? resource-ref? maybe-updated-refs)]}
-    (let [updated-refs (remove #(= (get refs-to-hashes %) (get old-resources %)) maybe-updated-refs)]
+    (let [new-resources-with-hash (merge-resource-hash refs-to-hashes (select-keys refs-to-resources maybe-updated-refs))
+          updated-resources (diff-resources-metadata old-resources new-resources-with-hash)]
 
-      (update! (:catalog-volatility metrics) (count updated-refs))
+      (update! (:catalog-volatility metrics) (count updated-resources))
 
-      (doseq [{:keys [type title] :as resource-ref} updated-refs]
+      (doseq [[{:keys [type title]} updated-cols] updated-resources]
         (sql/update-values :catalog_resources
                            ["catalog_id = ? and type = ? and title = ?" catalog-id type title]
-                           {:resource (get refs-to-hashes resource-ref)})))))
+                           (convert-tags-array updated-cols))))))
 
-(sm/defn add-resources!
+(defn strip-params
+  "Remove params from the resource as it is stored (and hashed) separately
+   from the resource metadata"
+  [resource]
+  (dissoc resource :parameters))
+
+(pls/defn-validated add-resources!
   "Persist the given resource and associate it with the given catalog."
   [catalog-id :- Number
    refs-to-resources :- resource-ref->resource-schema
    refs-to-hashes :- {resource-ref-schema String}]
-  (let [old-resources (catalog-resources catalog-id)]
+  (let [old-resources (catalog-resources catalog-id)
+        diffable-resources (kitchensink/mapvals strip-params refs-to-resources)]
     (sql/transaction
      (add-params! refs-to-resources refs-to-hashes)
      (utils/diff-fn old-resources
-                    refs-to-resources
+                    diffable-resources
                     (delete-catalog-resources! catalog-id)
-                    (insert-catalog-resources! catalog-id refs-to-hashes refs-to-resources)
-                    (update-catalog-resources! catalog-id refs-to-hashes old-resources)))))
+                    (insert-catalog-resources! catalog-id refs-to-hashes diffable-resources)
+                    (update-catalog-resources! catalog-id refs-to-hashes diffable-resources old-resources)))))
 
-(sm/defn catalog-edges-map
+(pls/defn-validated catalog-edges-map
   "Return all edges for a given catalog id as a map"
   [certname :- String]
   (sql/with-query-results result-set
@@ -448,7 +499,7 @@
     (zipmap (map vals result-set)
             (repeat nil))))
 
-(sm/defn delete-edges!
+(pls/defn-validated delete-edges!
   "Delete edges for a given certname.
 
   Edges must be either nil or a collection of lists containing each element
@@ -466,7 +517,7 @@
     (sql/delete-rows :edges
                      ["certname=? and source=? and target=? and type=?" certname source target type])))
 
-(sm/defn insert-edges!
+(pls/defn-validated insert-edges!
   "Insert edges for a given certname.
 
   Edges must be either nil or a collection of lists containing each element
@@ -485,7 +536,7 @@
       (update! (:catalog-volatility metrics) (count rows))
       (apply sql/insert-rows :edges rows))))
 
-(sm/defn replace-edges!
+(pls/defn-validated replace-edges!
   "Persist the given edges in the database
 
   Each edge is looked up in the supplied resources map to find a
@@ -511,7 +562,7 @@
                    #(delete-edges! certname %)
                    identity)))
 
-(sm/defn update-catalog-hash-match
+(pls/defn-validated update-catalog-hash-match
   "When a new incoming catalog has the same hash as an existing catalog, update metrics
    and the transaction id for the new catalog"
   [catalog-id :- Number
@@ -522,7 +573,7 @@
   (time! (:catalog-hash-match metrics)
          (update-catalog-metadata! catalog-id hash catalog timestamp)))
 
-(sm/defn update-catalog-associations!
+(pls/defn-validated update-catalog-associations!
   "Adds/updates/deletes the edges and resources for the given certname"
   [catalog-id :- Number
    {:keys [resources edges certname]} :- catalog-schema
@@ -532,7 +583,7 @@
   (time! (:add-edges metrics)
          (replace-edges! certname edges refs-to-hashes)))
 
-(sm/defn update-catalog-hash-miss
+(pls/defn-validated update-catalog-hash-miss
   "New catalogs for a given certname needs to have their metadata, resources and edges updated.  This
    function also outputs debugging related information when `catalog-hash-debug-dir` is not nil"
   [catalog-id :- Number
@@ -551,7 +602,7 @@
          (update-catalog-metadata! catalog-id hash catalog timestamp)
          (update-catalog-associations! catalog-id catalog refs-to-hashes)))
 
-(sm/defn add-new-catalog
+(pls/defn-validated add-new-catalog
   "Creates new catalog metadata and adds the proper associations for the edges and resources"
   [hash :- String
    catalog :- catalog-schema
@@ -562,7 +613,7 @@
          (let [catalog-id (:id (add-catalog-metadata! hash catalog timestamp))]
            (update-catalog-associations! catalog-id catalog refs-to-hashes))))
 
-(sm/defn add-catalog!
+(pls/defn-validated add-catalog!
   "Persist the supplied catalog in the database, returning its
    similarity hash. `catalog-hash-debug-dir` is an optional path that
    indicates where catalog debugging information should be stored."
@@ -573,8 +624,9 @@
     timestamp :- pls/Timestamp]
 
      (let [refs-to-hashes (time! (:resource-hashes metrics)
-                                 (zipmap (keys resources)
-                                         (map shash/resource-identity-hash (vals resources))))
+                                 (reduce-kv (fn [acc k v]
+                                              (assoc acc k (shash/resource-identity-hash v)))
+                                            {} resources))
            hash           (time! (:catalog-hash metrics)
                                  (shash/catalog-similarity-hash catalog))
            {id :id
@@ -623,7 +675,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Facts
 
-(sm/defn insert-facts!
+(pls/defn-validated insert-facts!
   "Given a certname and map of fact/value keypairs, insert them into the facts table"
   [certname :- String
    facts :- fact-map-schema]
@@ -632,7 +684,7 @@
                       (assoc default-row :name fact :value value))]
     (apply sql/insert-records :certname_facts rows)))
 
-(sm/defn add-facts!
+(pls/defn-validated add-facts!
   "Given a certname and a map of fact names to values, store records for those
   facts associated with the certname."
   [certname :- String
@@ -643,7 +695,7 @@
                      {:certname certname :timestamp (to-timestamp timestamp)})
   (insert-facts! certname facts))
 
-(sm/defn delete-facts!
+(pls/defn-validated delete-facts!
   "Delete all the facts (1 arg) or just the fact-names (2 args) for the given certname."
   ([certname :- String]
      (sql/delete-rows :certname_facts_metadata ["certname=?" certname]))
@@ -653,7 +705,7 @@
        (sql/delete-rows :certname_facts
                         (into [(str "certname=? and name " (jdbc/in-clause fact-names)) certname]  fact-names)))))
 
-(sm/defn cert-fact-map
+(pls/defn-validated cert-fact-map
   "Return all facts and their values for a given certname as a map"
   [certname :- String]
   (sql/with-query-results result-set
@@ -661,7 +713,7 @@
     (zipmap (map :name result-set)
             (map :value result-set))))
 
-(sm/defn update-existing-facts!
+(pls/defn-validated update-existing-facts!
   "Issues a SQL Update for `shared-keys` whose value in old-facts
    is different from new-facts"
   [certname :- String
@@ -674,7 +726,7 @@
       (when-not (= old-val new-val)
         (sql/update-values :certname_facts ["certname=? and name=?" certname k] {:value new-val})))))
 
-(sm/defn update-facts!
+(pls/defn-validated update-facts!
   "Given a certname, querys the DB for existing facts for that
    certname and will update, delete or insert the facts as necessary
    to match the facts argument."
@@ -691,7 +743,7 @@
                    #(insert-facts! certname (select-keys facts %))
                    #(update-existing-facts! certname old-facts facts %))))
 
-(sm/defn certname-facts-metadata!
+(pls/defn-validated certname-facts-metadata!
   "Return the certname_facts_metadata timestamp for the given certname, nil if not found"
   [certname :- String]
   (sql/with-query-results result-set
@@ -801,12 +853,12 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
 
-(sm/defn add-certname!
+(pls/defn-validated add-certname!
   "Add the given host to the db"
   [certname :- String]
   (sql/insert-record :certnames {:name certname}))
 
-(sm/defn maybe-activate-node!
+(pls/defn-validated maybe-activate-node!
   "Reactivate the given host, only if it was deactivated before `time`.
   Returns true if the node is activated, or if it was already active.
 
@@ -821,7 +873,7 @@
                                      {:deactivated nil})]
     (pos? (first replaced))))
 
-(sm/defn deactivate-node!
+(pls/defn-validated deactivate-node!
   "Deactivate the given host, recording the current time. If the node is
   currently inactive, no change is made."
   [certname :- String]
@@ -829,7 +881,7 @@
                     WHERE name=? AND deactivated IS NULL"
                    [(to-timestamp (now)) certname]))
 
-(sm/defn catalog-newer-than?
+(pls/defn-validated catalog-newer-than?
   "Returns true if the most current catalog for `certname` is more recent than
   `time`."
   [certname :- String
@@ -841,7 +893,7 @@
         (.after catalog-timestamp timestamp)
         false))))
 
-(sm/defn replace-catalog!
+(pls/defn-validated replace-catalog!
   "Given a catalog, replace the current catalog, if any, for its
   associated host with the supplied one. `catalog-hash-debug-dir`
   is an optional path that indicates where catalog debugging information
@@ -856,7 +908,7 @@
             (sql/transaction
              (add-catalog! catalog catalog-hash-debug-dir timestamp)))))
 
-(sm/defn replace-facts!
+(pls/defn-validated replace-facts!
   "Updates the facts of an existing node, if the facts are newer than the current set of facts.
    Adds all new facts if no existing facts are found. Invoking this function under the umbrella of
    a repeatable read or serializable transaction enforces only one update to the facts of a certname
@@ -870,7 +922,7 @@
              (update-facts! name values timestamp))
            (add-facts! name values timestamp))))
 
-(sm/defn add-report!
+(pls/defn-validated add-report!
   "Add a report and all of the associated events to the database."
   [report
    timestamp :- pls/Timestamp]
